@@ -19,14 +19,13 @@ set -e
 
 PYTHON_VERSION=${PYTHON_VERSION:-3.7}
 
-pip install -U -r .github/scripts/requirements.txt
-python setup.py develop
+pip install -e .[test]
 python -m pytest  # Run the tests without IPython.
 pip install ipython
 python -m pytest  # Now run the tests with IPython.
 pylint fire --ignore=test_components_py3.py,parser_fuzz_test.py,console
-if [[ ${PYTHON_VERSION} == 3.7 ]]; then
-  # Run type-checking.
-  pip install pytype;
-  pytype -x fire/test_components_py3.py;
+if [[ ${PYTHON_VERSION} == 3.12 ]]; then
+  # Run type-checking
+  pip install ty
+  python -m ty check --python $(which python) --exclude fire/test_components_py3.py --exclude fire/console/ --exclude fire/formatting_windows.py
 fi
