@@ -100,8 +100,6 @@ from fire.console import console_attr_os
 from fire.console import encoding as encoding_util
 from fire.console import text
 
-import six
-
 
 # TODO: Unify this logic with console.style.mappings
 class BoxLineCharacters(object):
@@ -268,7 +266,7 @@ class ConsoleAttr(object):
 
     # ANSI "standard" attributes.
     if self.SupportsAnsi():
-      # Select Graphic Rendition paramaters from
+      # Select Graphic Rendition parameters from
       # http://en.wikipedia.org/wiki/ANSI_escape_code#graphics
       # Italic '3' would be nice here but its not widely supported.
       self._csi = '\x1b['
@@ -288,7 +286,7 @@ class ConsoleAttr(object):
     elif self._encoding == 'cp437' and not is_screen_reader:
       self._box_line_characters = BoxLineCharactersUnicode()
       self._bullets = self._BULLETS_WINDOWS
-      # Windows does not suport the unicode characters used for the spinner.
+      # Windows does not support the unicode characters used for the spinner.
       self._progress_tracker_symbols = ProgressTrackerSymbolsAscii()
     else:
       self._box_line_characters = BoxLineCharactersAscii()
@@ -355,9 +353,9 @@ class ConsoleAttr(object):
     Returns:
       The console output string buf converted to unicode.
     """
-    if isinstance(buf, six.text_type):
+    if isinstance(buf, str):
       buf = buf.encode(self._encoding)
-    return six.text_type(buf, self._encoding, 'replace')
+    return str(buf, self._encoding, 'replace')
 
   def GetBoxLineCharacters(self):
     """Returns the box/line drawing characters object.
@@ -394,7 +392,7 @@ class ConsoleAttr(object):
     """Returns the control sequence indicator string.
 
     Returns:
-      The conrol sequence indicator string or None if control sequences are not
+      The control sequence indicator string or None if control sequences are not
       supported.
     """
     return self._csi
@@ -408,7 +406,7 @@ class ConsoleAttr(object):
       buf: The string to check for a control sequence.
 
     Returns:
-      The conrol sequence length at the beginning of buf or 0 if buf does not
+      The control sequence length at the beginning of buf or 0 if buf does not
       start with a control sequence.
     """
     if not self._csi or not buf.startswith(self._csi):
@@ -456,7 +454,7 @@ class ConsoleAttr(object):
     return self._get_raw_key[0]()
 
   def GetTermIdentifier(self):
-    """Returns the TERM envrionment variable for the console.
+    """Returns the TERM environment variable for the console.
 
     Returns:
       str: A str that describes the console's text capabilities
@@ -480,7 +478,7 @@ class ConsoleAttr(object):
     Returns:
       The display width of buf, handling unicode and ANSI controls.
     """
-    if not isinstance(buf, six.string_types):
+    if not isinstance(buf, str):
       # Handle non-string objects like Colorizer().
       return len(buf)
 
@@ -595,16 +593,16 @@ class Colorizer(object):
     self._justify = justify
 
   def __eq__(self, other):
-    return self._string == six.text_type(other)
+    return self._string == str(other)
 
   def __ne__(self, other):
     return not self == other
 
   def __gt__(self, other):
-    return self._string > six.text_type(other)
+    return self._string > str(other)
 
   def __lt__(self, other):
-    return self._string < six.text_type(other)
+    return self._string < str(other)
 
   def __ge__(self, other):
     return not self < other
@@ -692,7 +690,7 @@ def GetCharacterDisplayWidth(char):
   Returns:
     The monospaced terminal display width of char: either 0, 1, or 2.
   """
-  if not isinstance(char, six.text_type):
+  if not isinstance(char, str):
     # Non-unicode chars have width 1. Don't use this function on control chars.
     return 1
 
@@ -779,7 +777,7 @@ def EncodeToBytes(data):
     return data
 
   # Coerce to text that will be converted to bytes.
-  s = six.text_type(data)
+  s = str(data)
 
   try:
     # Assume the text can be directly converted to bytes (8-bit ascii).
