@@ -49,17 +49,11 @@ TODO(dbieber): Support these features.
 - "True | False" indicates bool type.
 """
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-
 import collections
+import enum
 import re
 import textwrap
 
-import enum
-
 
 class DocstringInfo(
     collections.namedtuple(
@@ -77,6 +71,11 @@ class ArgInfo(
 ArgInfo.__new__.__defaults__ = (None,) * len(ArgInfo._fields)
 
 
+class KwargInfo(ArgInfo):
+  pass
+KwargInfo.__new__.__defaults__ = (None,) * len(KwargInfo._fields)
+
+
 class Namespace(dict):
   """A dict with attribute (dot-notation) access enabled."""
 
@@ -108,7 +107,7 @@ class Formats(enum.Enum):
 
 
 SECTION_TITLES = {
-    Sections.ARGS: ('argument', 'arg', 'parameter', 'param'),
+    Sections.ARGS: ('argument', 'arg', 'parameter', 'param', 'key'),
     Sections.RETURNS: ('return',),
     Sections.YIELDS: ('yield',),
     Sections.RAISES: ('raise', 'except', 'exception', 'throw', 'error', 'warn'),
@@ -169,6 +168,7 @@ def parse(docstring):
   state.summary.lines = []
   state.description.lines = []
   state.args = []
+  state.kwargs = []
   state.current_arg = None
   state.returns.lines = []
   state.yields.lines = []
@@ -194,6 +194,10 @@ def parse(docstring):
       name=arg.name, type=_cast_to_known_type(_join_lines(arg.type.lines)),
       description=_join_lines(arg.description.lines)) for arg in state.args]
 
+  args.extend([KwargInfo(
+      name=arg.name, type=_cast_to_known_type(_join_lines(arg.type.lines)),
+      description=_join_lines(arg.description.lines)) for arg in state.kwargs])
+
   return DocstringInfo(
       summary=summary,
       description=description,
@@ -267,7 +271,7 @@ def _join_lines(lines):
   return '\n\n'.join(group_texts)
 
 
-def _get_or_create_arg_by_name(state, name):
+def _get_or_create_arg_by_name(state, name, is_kwarg=False):
   """Gets or creates a new Arg.
 
   These Arg objects (Namespaces) are turned into the ArgInfo namedtuples
@@ -277,17 +281,21 @@ def _get_or_create_arg_by_name(state, name):
   Args:
     state: The state of the parser.
     name: The name of the arg to create.
+    is_kwarg: A boolean representing whether the argument is a keyword arg.
   Returns:
     The new Arg.
   """
-  for arg in state.args:
+  for arg in state.args + state.kwargs:
     if arg.name == name:
       return arg
   arg = Namespace()  # TODO(dbieber): Switch to an explicit class.
   arg.name = name
   arg.type.lines = []
   arg.description.lines = []
-  state.args.append(arg)
+  if is_kwarg:
+    state.kwargs.append(arg)
+  else:
+    state.args.append(arg)
   return arg
 
 
@@ -295,9 +303,8 @@ def _is_arg_name(name):
   """Returns whether name is a valid arg name.
 
   This is used to prevent multiple words (plaintext) from being misinterpreted
-  as an argument name. So if ":" appears in the middle of a line in a docstring,
-  we don't accidentally interpret the first half of that line as a single arg
-  name.
+  as an argument name. Any line that doesn't match the pattern for a valid
+  argument is treated as not being an argument.
 
   Args:
     name: The name of the potential arg.
@@ -305,9 +312,11 @@ def _is_arg_name(name):
     True if name looks like an arg name, False otherwise.
   """
   name = name.strip()
-  return (name
-          and ' ' not in name
-          and ':' not in name)
+  # arg_pattern is a letter or underscore followed by
+  # zero or more letters, numbers, or underscores.
+  arg_pattern = r'^[a-zA-Z_]\w*$'
+  re.match(arg_pattern, name)
+  return re.match(arg_pattern, name) is not None
 
 
 def _as_arg_name_and_type(text):
@@ -390,6 +399,7 @@ def _consume_google_args_line(line_info, state):
         arg = _get_or_create_arg_by_name(state, arg_name)
         arg.type.lines.append(type_str)
         arg.description.lines.append(second.strip())
+        state.current_arg = arg
       else:
         if state.current_arg:
           state.current_arg.description.lines.append(split_line[0])
@@ -426,10 +436,14 @@ def _consume_line(line_info, state):
   if state.section.new and state.section.format == Formats.RST:
     # The current line starts with an RST directive, e.g. ":param arg:".
     directive = _get_directive(line_info)
-    directive_tokens = directive.split()  # pytype: disable=attribute-error
+    directive_tokens = directive.split()
     if state.section.title == Sections.ARGS:
       name = directive_tokens[-1]
-      arg = _get_or_create_arg_by_name(state, name)
+      arg = _get_or_create_arg_by_name(
+          state,
+          name,
+          is_kwarg=directive_tokens[0] == 'key'
+      )
       if len(directive_tokens) == 3:
         # A param directive of the form ":param type arg:".
         arg.type.lines.append(directive_tokens[1])
