@@ -14,12 +14,7 @@
 
 """Tests for the helptext module."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
-import sys
 import textwrap
 
 from fire import formatting
@@ -27,13 +22,12 @@ from fire import helptext
 from fire import test_components as tc
 from fire import testutils
 from fire import trace
-import six
 
 
 class HelpTest(testutils.BaseTestCase):
 
   def setUp(self):
-    super(HelpTest, self).setUp()
+    super().setUp()
     os.environ['ANSI_COLORS_DISABLED'] = '1'
 
   def testHelpTextNoDefaults(self):
@@ -129,12 +123,9 @@ class HelpTest(testutils.BaseTestCase):
         'Additional undocumented flags may also be accepted.',
         help_screen)
 
-  @testutils.skipIf(
-      sys.version_info[0:2] < (3, 5),
-      'Python < 3.5 does not support type hints.')
   def testHelpTextFunctionWithDefaultsAndTypes(self):
     component = (
-        tc.py3.WithDefaultsAndTypes().double)  # pytype: disable=module-attr
+        tc.py3.WithDefaultsAndTypes().double)
     help_screen = helptext.HelpText(
         component=component,
         trace=trace.FireTrace(component, name='double'))
@@ -146,12 +137,9 @@ class HelpTest(testutils.BaseTestCase):
         help_screen)
     self.assertNotIn('NOTES', help_screen)
 
-  @testutils.skipIf(
-      sys.version_info[0:2] < (3, 5),
-      'Python < 3.5 does not support type hints.')
   def testHelpTextFunctionWithTypesAndDefaultNone(self):
     component = (
-        tc.py3.WithDefaultsAndTypes().get_int)  # pytype: disable=module-attr
+        tc.py3.WithDefaultsAndTypes().get_int)
     help_screen = helptext.HelpText(
         component=component,
         trace=trace.FireTrace(component, name='get_int'))
@@ -164,11 +152,8 @@ class HelpTest(testutils.BaseTestCase):
         help_screen)
     self.assertNotIn('NOTES', help_screen)
 
-  @testutils.skipIf(
-      sys.version_info[0:2] < (3, 5),
-      'Python < 3.5 does not support type hints.')
   def testHelpTextFunctionWithTypes(self):
-    component = tc.py3.WithTypes().double  # pytype: disable=module-attr
+    component = tc.py3.WithTypes().double
     help_screen = helptext.HelpText(
         component=component,
         trace=trace.FireTrace(component, name='double'))
@@ -182,11 +167,8 @@ class HelpTest(testutils.BaseTestCase):
         'NOTES\n    You can also use flags syntax for POSITIONAL ARGUMENTS',
         help_screen)
 
-  @testutils.skipIf(
-      sys.version_info[0:2] < (3, 5),
-      'Python < 3.5 does not support type hints.')
   def testHelpTextFunctionWithLongTypes(self):
-    component = tc.py3.WithTypes().long_type  # pytype: disable=module-attr
+    component = tc.py3.WithTypes().long_type
     help_screen = helptext.HelpText(
         component=component,
         trace=trace.FireTrace(component, name='long_type'))
@@ -280,27 +262,20 @@ class HelpTest(testutils.BaseTestCase):
     self.assertIn('NAME\n    OldStyleEmpty', help_screen)
     self.assertIn('SYNOPSIS\n    OldStyleEmpty', help_screen)
 
-  @testutils.skipIf(
-      six.PY2, 'Python 2 does not support keyword-only arguments.')
   def testHelpTextKeywordOnlyArgumentsWithDefault(self):
-    component = tc.py3.KeywordOnly.with_default  # pytype: disable=module-attr
+    component = tc.py3.KeywordOnly.with_default
     output = helptext.HelpText(
         component=component, trace=trace.FireTrace(component, 'with_default'))
     self.assertIn('NAME\n    with_default', output)
     self.assertIn('FLAGS\n    -x, --x=X', output)
 
-  @testutils.skipIf(
-      six.PY2, 'Python 2 does not support keyword-only arguments.')
   def testHelpTextKeywordOnlyArgumentsWithoutDefault(self):
-    component = tc.py3.KeywordOnly.double  # pytype: disable=module-attr
+    component = tc.py3.KeywordOnly.double
     output = helptext.HelpText(
         component=component, trace=trace.FireTrace(component, 'double'))
     self.assertIn('NAME\n    double', output)
     self.assertIn('FLAGS\n    -c, --count=COUNT (required)', output)
 
-  @testutils.skipIf(
-      six.PY2,
-      'Python 2 does not support required name-only arguments.')
   def testHelpTextFunctionMixedDefaults(self):
     component = tc.py3.HelpTextComponent().identity
     t = trace.FireTrace(component, name='FunctionMixedDefaults')
@@ -453,7 +428,6 @@ VALUES
     self.assertIn('\n    --late', help_screen)
 
 
-
 class UsageTest(testutils.BaseTestCase):
 
   def testUsageOutput(self):
@@ -527,9 +501,6 @@ class UsageTest(testutils.BaseTestCase):
         textwrap.dedent(expected_output).lstrip('\n'),
         usage_output)
 
-  @testutils.skipIf(
-      six.PY2,
-      'Python 2 does not support required name-only arguments.')
   def testUsageOutputFunctionMixedDefaults(self):
     component = tc.py3.HelpTextComponent().identity
     t = trace.FireTrace(component, name='FunctionMixedDefaults')
