@@ -14,15 +14,11 @@
 
 """Tests for the interact module."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
+from unittest import mock
 
 from fire import interact
 from fire import testutils
 
-import mock
-
 
 try:
   import IPython  # pylint: disable=unused-import, g-import-not-at-top
